==> Bundle-Dependencies-Catalyst-0.07.tar.gz: Bundle-Dependencies-Catalyst-0.07/lib/Bundle/Dependencies/Catalyst.pm <==
package Bundle::Dependencies::Catalyst;

use strict;
use warnings;

our $VERSION = '0.07';

1;

__END__


=head1 NAME

Bundle::Dependencies::Catalyst - installs non-Catalyst prereqs

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Dependencies::Catalyst'
  
  
=head1 CONTENTS

Test::NoWarnings

Test::Tester

Test::Benchmark

Date::ICal

Devel::Symdump

Crypt::Rijndael

Unicode::Japanese

MIME::Tools

Tripletail

HTTP::Server::Simple::CGI

CGI::Application

I18N::LangTags

Locale::Maketext

ExtUtils::Constant

Cache::Memcached

Cache::Memcached::GetParserXS

Cache::Memcached::Indexable

Cache::Memcached::Tie

Cache::Memcached::Semaphore

Cache::Memcached::XS

Config

Errno

Error

version

Digest

Test::Simple

Getopt::Long

IO

XSLoader

File::Basename

Test::Exception

Module::Build::Compat

Cwd

CPAN

AutoLoader

HTML::Parser

Net::FTP

MIME::Base64

Compress::Zlib

YAML

File::Temp

HTTP::Body

Digest

Digest::MD5

CGI

CGI::Simple

DBI

IO::Util

Class::Util

Class::Accessor

Class::Accessor::Fast

Test::More

File::Path

Text::Balanced

URI

Tree::Simple

Tree::Simple::VisitorFactory

Class::Data::Inheritable

Class::Inspector

Data::Dump

File::Modified

HTML::Entities

HTTP::Headers

HTTP::Request::AsCGI

Module::Pluggable

NEXT

Path::Class

Scalar::Util

Text::SimpleTable

Time::HiRes

Text::Template

Template

HTML::Template

ExtUtils::Install

ExtUtils::ParseXS

IO::Zlib

Archive::Tar

Text::Diff

IO::String

PAR::Dist

Module::ScanDeps

File::Copy::Recursive

Test::Harness

YAML::Tiny

YAML::Syck

Module::Install

FormValidator::Simple

Template::Timer

HTML::Tagset

HTML::Parser

Class::DBI

Class::DBI::Plugin::Type

HTML::Element

Bit::Vector

Carp::Clan

Regexp::Common

MIME::Types

Image::Size

File::MMagic

Date::Calc

Data::FormValidator

File::Find

Bundle::DBI

DBIx::ContextualFetch

UNIVERSAL::moniker

Clone

List::Util

Ima::DBI

Class::Trigger

Template::Plugin::Class

Class::DBI::AsForm

Class::DBI::FromForm

Class::DBI

Socket

Net::SMTP

DateTime

DateTime::Format::Strptime

Email::Valid

Email::Valid::Loose

UNIVERSAL::require

Tie::IxHash

FormValidator::Simple

POE

Lingua::EN::Inflect

Class::DBI::Loader

Storable

Object::Signature

Test::Deep

Test::MockObject

MIME::Lite

MIME::Parser

Data::Dumper

Apache::Session

HTML::Mason

UNIVERSAL::isa

XML::NamespaceSupport

XML::SAX

XML::Parser

XML::SAX::Expat::Incremental

XML::SAX::ExpatNB

Encode

Encode::Alias

Encode::Guess

Encode::JP::H2Z

MIME::QuotedPrint

MIME::QuotedPrint::Perl

Email::MIME

Email::MIME::Encodings

Class::Publisher

DBI::DBD

DBD::SQLite

DBD::mysql

DBD::Pg

Class::Data::Accessor

SQL::Abstract

SQL::Abstract::Limit

Class::Accessor

Class::Accessor::Chained

Data::Page

DBIx::Class

DBIx::Class::Loader

Class::C3

Lingua::EN::Inflect::Number

App::Info

Chart::Strip

Roman

Text::Roman

Text::Unidecode

Text::Soundex

Date::Manip

Devel::StackTrace

Exception::Class

LWP::Authen::Wsse

ExtUtils::CBuilder

Params::Validate

Pod::Escapes

Text::Wrap

Pod::Simple

Pod::Man

Class::Singleton

DateTime::TimeZone

DateTime::Locale

Time::Local

XML::LibXML

XML::XPath

Digest::HMAC

Digest::MD5

Digest::SHA

Digest::SHA1

SHA

Config::Any

Test::use::ok

Locale::Maketext::Simple

Locale::Maketext::Lexicon

Text::vFile

Fcntl

Text::vCard

Math::BigInt

bignum

Math::BigRat

Math::BigInt::GMP

Math::BigInt::FastCalc

Math::BigInt

Net::IP

Net::DNS

Crypt::DH

Cache

Class::ErrorHandler

ExtUtils::AutoInstall

URI::Fetch

LWPx::ParanoidAgent

Net::OpenID::Consumer

HTML::Dojo

Net::Amazon

Log::Log4perl

I18N::LangTags::Detect

ExtUtils::Manifest

Mail::Address

FCGI

GSSAPI

Authen::SASL

XML::Stream

Net::XMPP

Net::Jabber

Data::UUID

Net::SSLeay

IO::Socket::SSL

SOAP::Lite

CGI

Term::ReadKey

Net::Blogger

Path::Class

Text::Markdown

Embperl

EVDB::API

XML::SAX::Base

XML::Filter::BufferText

Text::Iconv

XML::SAX::Exception

XML::SAX::Writer

URI::ldap

Algorithm::C3

Class::C3

Object::Signature

Test::use::ok

XML::LibXML

XML::LibXML::XPathContext

Digest::HMAC_SHA1

Net::Amazon::S3

IPC::ShareLite

Cache::FileCache

TextLinkAds

Class::Inspector

Pod::Usage

Test::WWW::Mechanize

Carp::Clan

DBIx::Class::Schema

Test::WWW::Mechanize::Catalyst

Set::Object

IO::LockedFile

Authen::Htpasswd

BerkeleyDB

Cache::Cache

Cache::BerkeleyDB

Hash::Merge

Template::Timer

CGI::FastTemplate

Template

Text::Template

HTML::Template

CGI::FormBuilder

Test::Harness

Test::Pod

Pod::Simple

Test::Builder

Test::Builder::Tester

Wx

Alien

Alien::wxWidgets

POE

POE::Session

POE::Loop::Wx

HTML::Template::Compiled

Jabber::Connection

Frontier::RPC2

Jabber::RPC

RPC::XML

IO::CaptureOutput

ClamAV::Client

Compress::Raw::Zlib

IO::Compress::Base

ExtUtils::Install

Class::Loader

Crypt::Random

Convert::ASN1

Class::ErrorHandler

Convert::PEM

Crypt::DES_EDE3

Digest::MD2

Data::Buffer

Convert::ASCII::Armour

Tie::EncryptedHash

Crypt::RIPEMD160

Crypt::Blowfish

Crypt::DES

Crypt::CBC

GnuPG

Crypt::IDEA

Crypt::OpenPGP

Pod::Coverage

Test::Pod

Test::Pod::Coverage

Digest::SHA::PurePerl

Digest::SHA

Digest::SHA256

File::Find::Rule

Module::CoreList

Module::Signature

Test::Distribution

Readonly

HTML::FillInForm

HTML::FillInForm::ForceUTF8

Catalyst::Plugin::RequestToken

GD

GD::Barcode

Data::Serializer

URI::Find

Data::Denter

Data::Taxi

Config::General

FreezeThaw

XML::Simple

Sub::Install

Log::Log4perl

Bundle::Net::LDAP

Digest::HMAC_MD5

WebService::Livedoor::Auth

Class::MixinFactory

Text::MicroMason

Devel::StackTrace

JSON

Yahoo::BBAuth

File::Slurp

Class::DBI::SQLite

Class::DBI::Pager

DBI::Shell

IPC::Run

GraphViz

Catalyst::View::GraphViz

XML::Feed

Data::Visitor

Config::Any

FindBin::Real

Return::Value

Email::Address

Email::Simple

Email::Send

Email::MIME::Encodings

Sys::Hostname

Email::MessageID

Email::Simple::Creator

Email::MIME::Creator

Email::MIME

Email::Send

Rose::URI

Rose::DateTime

Rose::Object

Clone::PP

Rose::HTML::Objects

Data::Page

Rose::HTMLx::Form::Field::Autocomplete

Sort::SQL

Data::Pageset

SQL::ReservedWords

DateTime::Format::Builder

DateTime::Format::MySQL

DateTime::Format::Pg

List::MoreUtils

Time::Clock

Class::ISA

Path::Class::File::Stat

SWISH::API::More

SWISH::API::Object

SWISH::API::Stat

SWISH::API::Common

Sys::SigAction

GD

GD::SecurityImage

Set::Crontab

DateTime::Set

POE

POE::Component::Cron

HTML::AjaxTags

HTML::AjaxTags::TT

HTTP::MobileAgent

Syntax::Highlight::Universal

Pod::ParseUtils

Pod::Parser

Pod::ProjectDocs

Jcode

Cache::FastMmap

Template::Provider::Encoding

XML::LibXSLT

Module::Load

Module::Load::Conditional

Params::Check

Log::Message

Params::Profile

RPC::XML::Parser

RPC::XML::Parser::XS

JSON::Any

Jemplate

HTTP::MobileUserID

XML::Atom

DateTime::Format::W3CDTF

HTTP::Parser

Net::Server

Class::DBI::Plugin::RetrieveAll

Class::DBI::Sweet

DBIx::DBSchema

DateTime::Format::ISO8601

Exporter::Lite

DateTime::Format::ISO8601

Sub::Uplevel

Sub::Override

Object::Declare

Class::ISA

base

Class::InsideOut

Scalar::Defer

String::CRC32

Time::Local

Date::Range

Time::Piece

Date::Simple

File::Find::Rule

Attribute::Handlers

Test::Class

Test::Harness

String::Escape

URI::Escape

HTTP::BrowserDetect

Compress::Bzip2

IP::Country

Geography::Countries

Class::Publisher

HTML::Tree

HTML::Prototype

Set::Crontab

Set::Scalar

DateTime::Set

DateTime::Event::Cron

File::BaseDir

HTML::SuperForm

CGI::Simple::Cookie

Tree::Simple::Visitor::FindByPath

Tree::Simple::VisitorFactory

Test::LongString

CSS::Squish

MKDoc::XML

Petal

HTML::Scrubber

HTML::Widget

HTML::Widget::JavaScript

PadWalker

Devel::LexAlias

Devel::Caller

Array::RefElem

Class::Throwable

Task::Weaken

Sub::Install

Data::OptList

Params::Util

Sub::Exporter

Sub::Name

Class::MOP

Moose

WWW::Mechanize

HTTP::Server::Simple

Carp::Assert::More

URI::file

Test::WWW::Mechanize

CGI::Expand

URI::URL

HTML::TokeParser::Simple

Cache::Memcached::Managed

CGI::FormBuilder

HTML::Template

Text::Template

CGI::FastTemplate

Log::Handler

Devel::Backtrace

Apache::Session::Flex

Authen::PAM

Data::Types

Class::Observable

Class::Date

Business::ISBN::Data

Business::ISBN

Class::Std

Date::Parse

WebService::ISBNDB

Cache::Memcached

DateTime::Format::HTTP

Log::Dispatch

IPC::Shareable

IPC::SharedCache

IPC::SysV

Text::Textile

SVG::TT::Graph

Memoize

Scalar::Listify

List::Rotation::Cycle

Class::Prototyped

HTML::PrettyPrinter

HTML::Element::Library

Template::Filters::LazyLoader

Module::Recursive::Require

CGI::Untaint

DBIx::Simple

Term::ANSIColor

CGI::Session

CGI::Carp

XML::Parser::Lite::Tree

Flickr::API

Hatena::API::Auth

DateTime::Format::Mail

MIME::Lite::TT

MIME::Lite::TT::Japanese

MIME::Lite::TT:HTML::Japanese

OLE::Storage_Lite

Text::TabularDisplay

Readonly::XS

Test::Differences

XML::Writer

Text::RecordParser

Text::ParseWords

Spreadsheet::ParseExcel

GraphViz

Class::MakeMethods

Class::Base

Class::DBI::DATA::Schema

SQL::Translator

Module::Pluggable::Ordered

Mail::ListDetector

Email::Abstract

Email::Date

Email::Store

HTML::Widget::DBIC

CGI::Fast

FCGI::ProcManager

Image::Magick

Image::Magick::Thumbnail::Fixed

IO::WrapTie

MogileFS::Client

FCGI::ProcManager


=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

1;

==> Bundle-Dependencies-Catalyst-0.08.tar.gz: Bundle-Dependencies-Catalyst-0.08/lib/Bundle/Dependencies/Catalyst.pm <==
package Bundle::Dependencies::Catalyst;

use strict;
use warnings;

our $VERSION = '0.08';

1;

__END__


=head1 NAME

Bundle::Dependencies::Catalyst - installs non-Catalyst prereqs

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Dependencies::Catalyst'
  
  
=head1 CONTENTS

Test::NoWarnings

Test::Tester

Test::Benchmark

Date::ICal

Devel::Symdump

Crypt::Rijndael

Unicode::Japanese

MIME::Tools

Tripletail

HTTP::Server::Simple::CGI

CGI::Application

I18N::LangTags

Locale::Maketext

ExtUtils::Constant

Cache::Memcached

Cache::Memcached::GetParserXS

Cache::Memcached::Indexable

Cache::Memcached::Tie

Cache::Memcached::Semaphore

Cache::Memcached::XS

Config

Errno

Error

version

Digest

Test::Simple

Getopt::Long

IO

XSLoader

File::Basename

Test::Exception

Module::Build::Compat

Cwd

CPAN

AutoLoader

HTML::Parser

Net::FTP

MIME::Base64

Compress::Zlib

YAML

File::Temp

HTTP::Body

Digest

Digest::MD5

CGI

CGI::Simple

DBI

IO::Util

Class::Util

Class::Accessor

Class::Accessor::Fast

Test::More

File::Path

Text::Balanced

URI

Tree::Simple

Tree::Simple::VisitorFactory

Class::Data::Inheritable

Class::Inspector

Data::Dump

File::Modified

HTML::Entities

HTTP::Headers

HTTP::Request::AsCGI

Module::Pluggable

NEXT

Path::Class

Scalar::Util

Text::SimpleTable

Time::HiRes

Text::Template

Template

HTML::Template

ExtUtils::Install

ExtUtils::ParseXS

IO::Zlib

Archive::Tar

Text::Diff

IO::String

PAR::Dist

Module::ScanDeps

File::Copy::Recursive

Test::Harness

YAML::Tiny

YAML::Syck

Module::Install

FormValidator::Simple

Template::Timer

HTML::Tagset

HTML::Parser

Class::DBI

Class::DBI::Plugin::Type

HTML::Element

Bit::Vector

Carp::Clan

Regexp::Common

MIME::Types

Image::Size

File::MMagic

Date::Calc

Data::FormValidator

File::Find

Bundle::DBI

DBIx::ContextualFetch

UNIVERSAL::moniker

Clone

List::Util

Ima::DBI

Class::Trigger

Template::Plugin::Class

Class::DBI::AsForm

Class::DBI::FromForm

Class::DBI

Socket

Net::SMTP

DateTime

DateTime::Format::Strptime

Email::Valid

Email::Valid::Loose

UNIVERSAL::require

Tie::IxHash

FormValidator::Simple

POE

Lingua::EN::Inflect

Class::DBI::Loader

Storable

Object::Signature

Test::Deep

Test::MockObject

MIME::Lite

MIME::Parser

Data::Dumper

Apache::Session

HTML::Mason

UNIVERSAL::isa

XML::NamespaceSupport

XML::SAX

XML::Parser

XML::SAX::Expat::Incremental

XML::SAX::ExpatNB

Encode

Encode::Alias

Encode::Guess

Encode::JP::H2Z

MIME::QuotedPrint

MIME::QuotedPrint::Perl

Email::MIME

Email::MIME::Encodings

Class::Publisher

DBI::DBD

DBD::SQLite

DBD::mysql

DBD::Pg

Class::Data::Accessor

SQL::Abstract

SQL::Abstract::Limit

Class::Accessor

Class::Accessor::Chained

Data::Page

DBIx::Class

DBIx::Class::Loader

Class::C3

Lingua::EN::Inflect::Number

App::Info

Chart::Strip

Roman

Text::Roman

Text::Unidecode

Text::Soundex

Date::Manip

Devel::StackTrace

Exception::Class

LWP::Authen::Wsse

ExtUtils::CBuilder

Params::Validate

Pod::Escapes

Text::Wrap

Pod::Simple

Pod::Man

Class::Singleton

DateTime::TimeZone

DateTime::Locale

Time::Local

XML::LibXML

XML::XPath

Digest::HMAC

Digest::MD5

Digest::SHA

Digest::SHA1

SHA

Config::Any

Test::use::ok

Locale::Maketext::Simple

Locale::Maketext::Lexicon

Text::vFile

Fcntl

Text::vCard

Math::BigInt

bignum

Math::BigRat

Math::BigInt::GMP

Math::BigInt::FastCalc

Math::BigInt

Net::IP

Net::DNS

Crypt::DH

Cache

Class::ErrorHandler

ExtUtils::AutoInstall

URI::Fetch

LWPx::ParanoidAgent

Net::OpenID::Consumer

HTML::Dojo

Net::Amazon

Log::Log4perl

I18N::LangTags::Detect

ExtUtils::Manifest

Mail::Address

FCGI

GSSAPI

Authen::SASL

XML::Stream

Net::XMPP

Net::Jabber

Data::UUID

Net::SSLeay

IO::Socket::SSL

SOAP::Lite

CGI

Term::ReadKey

Net::Blogger

Path::Class

Text::Markdown

Embperl

EVDB::API

XML::SAX::Base

XML::Filter::BufferText

Text::Iconv

XML::SAX::Exception

XML::SAX::Writer

URI::ldap

Algorithm::C3

Class::C3

Object::Signature

Test::use::ok

XML::LibXML

XML::LibXML::XPathContext

Digest::HMAC_SHA1

Net::Amazon::S3

IPC::ShareLite

Cache::FileCache

TextLinkAds

Class::Inspector

Pod::Usage

Test::WWW::Mechanize

Carp::Clan

DBIx::Class::Schema

Test::WWW::Mechanize::Catalyst

Set::Object

IO::LockedFile

Authen::Htpasswd

BerkeleyDB

Cache::Cache

Cache::BerkeleyDB

Hash::Merge

Template::Timer

CGI::FastTemplate

Template

Text::Template

HTML::Template

CGI::FormBuilder

Test::Harness

Test::Pod

Pod::Simple

Test::Builder

Test::Builder::Tester

Wx

Alien

Alien::wxWidgets

POE

POE::Session

POE::Loop::Wx

HTML::Template::Compiled

Jabber::Connection

Frontier::RPC2

Jabber::RPC

RPC::XML

IO::CaptureOutput

ClamAV::Client

Compress::Raw::Zlib

IO::Compress::Base

ExtUtils::Install

Class::Loader

Crypt::Random

Convert::ASN1

Class::ErrorHandler

Convert::PEM

Crypt::DES_EDE3

Digest::MD2

Data::Buffer

Convert::ASCII::Armour

Tie::EncryptedHash

Crypt::RIPEMD160

Crypt::Blowfish

Crypt::DES

Crypt::CBC

GnuPG

Crypt::IDEA

Crypt::OpenPGP

Pod::Coverage

Test::Pod

Test::Pod::Coverage

Digest::SHA::PurePerl

Digest::SHA

Digest::SHA256

File::Find::Rule

Module::CoreList

Module::Signature

Test::Distribution

Readonly

HTML::FillInForm

HTML::FillInForm::ForceUTF8

Catalyst::Plugin::RequestToken

GD

GD::Barcode

Data::Serializer

URI::Find

Data::Denter

Data::Taxi

Config::General

FreezeThaw

XML::Simple

Sub::Install

Log::Log4perl

Bundle::Net::LDAP

Digest::HMAC_MD5

WebService::Livedoor::Auth

Class::MixinFactory

Text::MicroMason

Devel::StackTrace

JSON

Yahoo::BBAuth

File::Slurp

Class::DBI::SQLite

Class::DBI::Pager

DBI::Shell

IPC::Run

GraphViz

Catalyst::View::GraphViz

XML::Feed

Data::Visitor

Config::Any

FindBin::Real

Return::Value

Email::Address

Email::Simple

Email::Send

Email::MIME::Encodings

Sys::Hostname

Email::MessageID

Email::Simple::Creator

Email::MIME::Creator

Email::MIME

Email::Send

Rose::URI

Rose::DateTime

Rose::Object

Clone::PP

Rose::HTML::Objects

Data::Page

Rose::HTMLx::Form::Field::Autocomplete

Sort::SQL

Data::Pageset

SQL::ReservedWords

DateTime::Format::Builder

DateTime::Format::MySQL

DateTime::Format::Pg

List::MoreUtils

Time::Clock

Class::ISA

Path::Class::File::Stat

SWISH::API::More

SWISH::API::Object

SWISH::API::Stat

SWISH::API::Common

Sys::SigAction

GD

GD::SecurityImage

Set::Crontab

DateTime::Set

POE

POE::Component::Cron

HTML::AjaxTags

HTML::AjaxTags::TT

HTTP::MobileAgent

Syntax::Highlight::Universal

Pod::ParseUtils

Pod::Parser

Pod::ProjectDocs

Jcode

Cache::FastMmap

Template::Provider::Encoding

XML::LibXSLT

Module::Load

Module::Load::Conditional

Params::Check

Log::Message

Params::Profile

RPC::XML::Parser

RPC::XML::Parser::XS

JSON::Any

Jemplate

HTTP::MobileUserID

XML::Atom

DateTime::Format::W3CDTF

HTTP::Parser

Net::Server

Class::DBI::Plugin::RetrieveAll

Class::DBI::Sweet

DBIx::DBSchema

DateTime::Format::ISO8601

Exporter::Lite

DateTime::Format::ISO8601

Sub::Uplevel

Sub::Override

Object::Declare

Class::ISA

base

Class::InsideOut

Scalar::Defer

String::CRC32

Time::Local

Date::Range

Time::Piece

Date::Simple

File::Find::Rule

Attribute::Handlers

Test::Class

Test::Harness

String::Escape

URI::Escape

HTTP::BrowserDetect

Compress::Bzip2

IP::Country

Geography::Countries

Class::Publisher

HTML::Tree

HTML::Prototype

Set::Crontab

Set::Scalar

DateTime::Set

DateTime::Event::Cron

File::BaseDir

HTML::SuperForm

CGI::Simple::Cookie

Tree::Simple::Visitor::FindByPath

Tree::Simple::VisitorFactory

Test::LongString

CSS::Squish

MKDoc::XML

Petal

HTML::Scrubber

HTML::Widget

HTML::Widget::JavaScript

PadWalker

Devel::LexAlias

Devel::Caller

Array::RefElem

Class::Throwable

Task::Weaken

Sub::Install

Data::OptList

Params::Util

Sub::Exporter

Sub::Name

Class::MOP

Moose

WWW::Mechanize

HTTP::Server::Simple

Carp::Assert::More

URI::file

Test::WWW::Mechanize

CGI::Expand

URI::URL

HTML::TokeParser::Simple

Cache::Memcached::Managed

CGI::FormBuilder

HTML::Template

Text::Template

CGI::FastTemplate

Log::Handler

Devel::Backtrace

Apache::Session::Flex

Authen::PAM

Data::Types

Class::Observable

Class::Date

Business::ISBN::Data

Business::ISBN

Class::Std

Date::Parse

WebService::ISBNDB

Cache::Memcached

DateTime::Format::HTTP

Log::Dispatch

IPC::Shareable

IPC::SharedCache

IPC::SysV

Text::Textile

SVG::TT::Graph

Memoize

Scalar::Listify

List::Rotation::Cycle

Class::Prototyped

HTML::PrettyPrinter

HTML::Element::Library

Template::Filters::LazyLoader

Module::Recursive::Require

CGI::Untaint

DBIx::Simple

Term::ANSIColor

CGI::Session

CGI::Carp

XML::Parser::Lite::Tree

Flickr::API

Hatena::API::Auth

DateTime::Format::Mail

MIME::Lite::TT

MIME::Lite::TT::Japanese

MIME::Lite::TT::HTML::Japanese

OLE::Storage_Lite

Text::TabularDisplay

Readonly::XS

Test::Differences

XML::Writer

Text::RecordParser

Text::ParseWords

Spreadsheet::ParseExcel

GraphViz

Class::MakeMethods

Class::Base

Class::DBI::DATA::Schema

SQL::Translator

Module::Pluggable::Ordered

Mail::ListDetector

Email::Abstract

Email::Date

Email::Store

HTML::Widget::DBIC

CGI::Fast

FCGI::ProcManager

IO::WrapTie

MogileFS::Client

FCGI::ProcManager


=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

1;
